<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:date="http://www.jclark.com/xt/java/java.util.Date" 
	xmlns:saxon="http://icl.com/saxon" 
	xmlns:xt="http://www.jclark.com/xt" 
	extension-element-prefixes="saxon xt"
	xmlns:ditamsg="http://dita-ot.sourceforge.net/ns/200704/ditamsg"
    xmlns:related-links="http://dita-ot.sourceforge.net/ns/200709/related-links"
    exclude-result-prefixes="related-links ditamsg"
	>


<!--
##### STYLESHEET IMPORTS #####
the main dita to xhtml converter 
-->
<xsl:import href="idit2htm.xsl"/>

<!-- Turn off all the task label headings -->
<!-- 20090716:jta disabled, UA defect 8248 -->
<!-- xsl:param name="GENERATE-TASK-LABELS" select="'NO'"/ -->

<!-- We can turn off default class attributes for IDWB 4.1 by uncommenting the following line -->
<!-- xsl:param name="PRESERVE-DITA-CLASS" select="'no'"/ -->

<!-- 
##### XHTML OUTPUT HEADER INFO #####
Output XHTML with Saxon:xhtml syntax; use UFT-8 encoding="UTF-8"; transitional XHTML.  
Prevent indenting to conserve space on output.
20080709:JA changed method="saxon:xhtml" to method="xml" for Saxon 9/IDWB 4.0
20090408:JA changed method="xml" to "xhtml" for IDWB 4.1
20100218:JA added new template for IDWB 4.2 related links override for showmes
-->
<xsl:output method="xhtml"
            encoding="UTF-8"
            indent="no"
            doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
            doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
/>


<!--
##### HEADER: GENERATED TIMESTAMP   #####
-->
<xsl:template name="chapterHead">
  <head><xsl:value-of select="$newline"/>
    <!-- initial meta information -->
    <xsl:call-template name="generateCharset"/>   <!-- Set the character set to UTF-8 -->
    <xsl:call-template name="generateDefaultCopyright"/> <!-- Generate a default copyright, if needed -->
    <xsl:call-template name="generateDefaultMeta"/> <!-- Standard meta for security, robots, etc -->
    <xsl:call-template name="getMeta"/>           <!-- Process metadata from topic prolog -->
    <!-- 20090409:JA override adds next line -->
    <xsl:call-template name="generated-date"/>  <!-- Add generated timestamp -->
    <xsl:call-template name="copyright"/>         <!-- Generate copyright, if specified manually -->
    <xsl:call-template name="generateCssLinks"/>  <!-- Generate links to CSS files -->
     <xsl:call-template name="generateAccLinks"/>  <!-- Generate Accessibility links start/prev/next files -->
    <xsl:call-template name="generateChapterTitle"/> <!-- Generate the <title> element -->
    <xsl:call-template name="gen-user-head" />    <!-- include user's XSL HEAD processing here -->
    <xsl:call-template name="gen-user-scripts" /> <!-- include user's XSL javascripts here -->
    <xsl:call-template name="gen-user-styles" />  <!-- include user's XSL style element and content here -->
    <xsl:call-template name="processHDF"/>        <!-- Add user HDF file, if specified -->
  </head>
  <xsl:value-of select="$newline"/>
</xsl:template>

<xsl:template name="generated-date">
    <xsl:if test="function-available('date:to-string') and function-available('date:new')">
      <!-- 20090519:JA changes to prevent qualifier from being updated every build; defect 7329 
      <xsl:element name="meta">
        <xsl:attribute name="name">Generated</xsl:attribute>
        <xsl:attribute name="content"><xsl:value-of select="date:to-string(date:new())"/></xsl:attribute>
      </xsl:element> -->
      <xsl:comment> Generated date: <xsl:value-of select="date:to-string(date:new())"/> </xsl:comment>
      <xsl:value-of select="$newline"/>      
    </xsl:if>
</xsl:template>

<!--
##### SHOWME: IDWB 4.2 RELATED LINK OVERRIDE #####
Overriding related-links templates to ignore showme links that are listed in the related links area
-->

<xsl:template match="*[contains(@class, ' topic/link ')][@type='showme']">
	<!-- do nothing -->
</xsl:template>

  <!-- 
  ##### SHOWME: SHORTDESC OVERRIDE #####
  Overrides shortdesc template to place code showme viewlet above the shortdesc tag.  This is how showme's get to the top of the page.
  Styles and images are called from collapse.js; movie image is in the Tutorials Gallery common files
  11/18/08 sjp duplicated otherprops WidthxHeight resize code 
  11/18/08 sjp duplicated the virtual link availability for the href attribute in Showme related links. 
  -->
  <xsl:template match="*[contains(@class,' topic/shortdesc ')]" mode="outofline">
    <div>
      <xsl:for-each select="following-sibling::*[contains(@class,' topic/related-links ')]/descendant::*[contains(@class,' topic/link ')][@format='viewlet'][@type='showme']">
      <xsl:variable name="linkhref">
         <xsl:value-of select="replace(@href,'\\','/')"/>
      </xsl:variable>
      <xsl:variable name="hrefpath">
         <xsl:if test="not(contains($linkhref,'/'))">
            <xsl:if test="not(contains($linkhref,'.swf'))">../swf/</xsl:if>
         </xsl:if>
      </xsl:variable>
      <xsl:variable name="hrefext">
         <xsl:if test="not(contains($linkhref,'.swf'))">.swf</xsl:if>
      </xsl:variable>
      <xsl:variable name="vidhref">
         <xsl:value-of select="concat($hrefpath,$linkhref,$hrefext)"/>
      </xsl:variable>
      <div class="showme">
      <div class="collapseheadshowme">
        <a href="javascript:void(0)"
           class="collapsehead"
           onclick="collapse(this)">
           <!-- <img src="../../com.ibm.help.doc/images/camera2.gif" border="none" align="middle" alt=""></img> -->
           <xsl:value-of select="." /></a>
      </div>
      <div class="collapsecontent">
        <div class="section">
        <xsl:choose>
            <!-- Parse values of 'otherprops' attribute. -->
            <xsl:when test="boolean(@otherprops)">
              <xsl:variable name="width">
                <xsl:value-of select="substring-before(@otherprops, 'x')" />
              </xsl:variable>
              <xsl:variable name="height">
                <xsl:value-of select="substring-after(@otherprops, 'x')" />
              </xsl:variable>
              <xsl:element name="object">
                <xsl:attribute name="id">11</xsl:attribute>
                <xsl:attribute name="codebase">http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab</xsl:attribute>
                <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
                <xsl:attribute name="classid">clsid:D27CDB6E-AE6D-11cf-96B8-444553540000</xsl:attribute>
                <xsl:attribute name="data"><xsl:value-of select="$vidhref" /></xsl:attribute>
                <xsl:attribute name="width"><xsl:value-of select="$width" /></xsl:attribute>
                <xsl:attribute name="height"><xsl:value-of select="$height" /></xsl:attribute>
                <xsl:element name="param">
                  <xsl:attribute name="name">movie</xsl:attribute>
                  <xsl:attribute name="value"><xsl:value-of select="$vidhref" /></xsl:attribute>
                </xsl:element>
                <xsl:element name="param">
                  <xsl:attribute name="name">pluginspace</xsl:attribute>
                  <xsl:attribute name="value">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
                </xsl:element>
                <xsl:element name="embed">
                  <xsl:attribute name="name">11</xsl:attribute>
                  <xsl:attribute name="width"><xsl:value-of select="$width" /></xsl:attribute>
                  <xsl:attribute name="height"><xsl:value-of select="$height" /></xsl:attribute>
                  <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
                  <xsl:attribute name="pluginspace">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
                  <xsl:attribute name="src"><xsl:value-of select="$vidhref" /></xsl:attribute>
                </xsl:element>
              </xsl:element>
            </xsl:when>
            <!-- Default values for width and height attributes. -->
            <xsl:otherwise>
              <xsl:element name="object">
                <xsl:attribute name="id">11</xsl:attribute>
                <xsl:attribute name="codebase">http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab</xsl:attribute>
                <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
                <xsl:attribute name="classid">clsid:D27CDB6E-AE6D-11cf-96B8-444553540000</xsl:attribute>
                <xsl:attribute name="data"><xsl:value-of select="$vidhref" /></xsl:attribute>
                <xsl:attribute name="width">800</xsl:attribute>
                <xsl:attribute name="height">600</xsl:attribute>
                <xsl:element name="param">
                  <xsl:attribute name="name">movie</xsl:attribute>
                  <xsl:attribute name="value"><xsl:value-of select="$vidhref" /></xsl:attribute>
                </xsl:element>
                <xsl:element name="param">
                  <xsl:attribute name="name">pluginspace</xsl:attribute>
                  <xsl:attribute name="value">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
                </xsl:element>
                <xsl:element name="embed">
                  <xsl:attribute name="name">11</xsl:attribute>
                  <xsl:attribute name="width">800</xsl:attribute>
                  <xsl:attribute name="height">600</xsl:attribute>
                  <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
                  <xsl:attribute name="pluginspace">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
                  <xsl:attribute name="src"><xsl:value-of select="$vidhref" /></xsl:attribute>
                </xsl:element>
              </xsl:element>
            </xsl:otherwise>
          </xsl:choose>
        </div>
      </div>
      </div>
       </xsl:for-each>
      <xsl:apply-templates/>
    </div>
  </xsl:template>
  
<!-- 
##### IMAGES: OVERRIDES FOR IMAGE RESIZE ##### 
these are based on IDWB 3.8.3 templates 
additions or changes noted by ****** 
updated 06/14/2006 jta                                 
-->
<xsl:variable name="jscriptonload">javascript:resizeAtPageLoad();</xsl:variable> <!-- jta added 06/14/2006 ****** -->
<xsl:variable name="jscriptresize">javascript:resizeAllImages();</xsl:variable>  <!-- jta added 06/14/2006 ****** -->

<!-- 
##### IMAGES: NEEDED FOR IMAGE RESIZING #####
can go away if not resizing images in docs
-->

<xsl:template name="chapterBody">
    <body>
      <!-- Already put xml:lang on <html>; do not copy to body with commonattributes -->
      <xsl:call-template name="setonresize"/> <!-- ****** -->
      <xsl:call-template name="setidaname"/>
      <xsl:value-of select="$newline"/>
      <xsl:call-template name="flagit"/>
      <xsl:call-template name="start-revflag"/>
      <xsl:call-template name="generateBreadcrumbs"/>
      <xsl:call-template name="gen-user-header"/>  <!-- include user's XSL running header here -->
      <xsl:call-template name="processHDR"/>
      <!-- Include a user's XSL call here to generate a toc based on what's a child of topic -->
      <xsl:call-template name="gen-user-sidetoc"/>
      <xsl:apply-templates/> <!-- this will include all things within topic; therefore, -->
      <!-- title content will appear here by fall-through -->
      <!-- followed by prolog (but no fall-through is permitted for it) -->
      <!-- followed by body content, again by fall-through in document order -->
      <!-- followed by related links -->
      <!-- followed by child topics by fall-through -->
      
      <xsl:call-template name="gen-endnotes"/>    <!-- include footnote-endnotes -->
      <xsl:call-template name="gen-user-footer"/> <!-- include user's XSL running footer here -->
      <xsl:call-template name="processFTR"/>      <!-- Include XHTML footer, if specified -->
      <xsl:call-template name="end-revflag"/>
    </body>
    <xsl:value-of select="$newline"/>
  </xsl:template>

<!-- ****** -->
<xsl:template name="setonresize">
 <!-- jta added below 06/14/2006 -->
 <xsl:attribute name="onload">
   <xsl:value-of select="$jscriptonload"/>
 </xsl:attribute>
 <xsl:attribute name="onresize">
   <!-- jta removed 06/14/2006 <xsl:value-of select="$jscriptreload"/> -->
   <xsl:value-of select="$jscriptresize"/>
 </xsl:attribute>
</xsl:template>


<!--
##### FIXES FOR ECLIPSE EXTENSIONS #####
-->

<!-- Revert to pre-IDWB 4.1 method of outputclass handling -->
  <!-- xsl:template name="commonattribute">
    <xsl:message terminate="yes">Commonattribute template <xsl:value-of select="."/></xsl:message>    
    <xsl:apply-templates select="@xml:lang"/>
    <xsl:apply-templates select="@outputclass"/>
    <xsl:apply-templates select="@dir"/>
  </xsl:template -->

<!-- Locates elements that have an outputclass attribute that contains
  'include' and replaces it with an include element. -->
  <!-- Amended to avoid avoid duplicate rule matches with the topic.p template.
       dwh 21.Aug.2006 -->
  <xsl:template match="//*[not(contains(@class,' topic/p ')) and contains(@outputclass, 'include')]">
    <xsl:element name="include">
      <xsl:attribute name="path"><xsl:value-of select="substring-after(@outputclass, 'include_')" /></xsl:attribute>
    </xsl:element>
    <xsl:apply-templates />
  </xsl:template>


  <!-- Locates elements that have an outputclass attribute that contains
  'anchor' and replaces it with an anchor element. -->
  <!-- Amended to avoid avoid duplicate rule matches with the topic.p template.
       dwh 21.Aug.2006 -->
  <xsl:template match="//*[not(contains(@class,' topic/p ')) and contains(@outputclass, 'anchor_')]">
    <xsl:element name="anchor">
      <xsl:attribute name="id"><xsl:value-of select="substring-after(@outputclass, 'anchor_')" /></xsl:attribute>
    </xsl:element>
    <xsl:apply-templates />
  </xsl:template>

<!-- Set the class attribute on the resulting output element. The default for a class of elements
     may be passed in with $default, but that default can be overridden with mode="get-output-class". -->
<xsl:template match="*" mode="set-output-class">
  <xsl:param name="default"/>
  <xsl:variable name="output-class">
    <xsl:apply-templates select="." mode="get-output-class"/>
  </xsl:variable>
  <xsl:variable name="using-output-class">
    <xsl:choose>
      <xsl:when test="string-length(normalize-space($output-class)) &gt; 0"><xsl:value-of select="$output-class"/></xsl:when>
      <xsl:when test="string-length(normalize-space($default)) &gt; 0"><xsl:value-of select="$default"/></xsl:when>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="ancestry">
    <xsl:if test="$PRESERVE-DITA-CLASS='yes'">
      <xsl:apply-templates select="." mode="get-element-ancestry"/>
    </xsl:if>
  </xsl:variable>
  <xsl:variable name="outputclass-attribute">
    <xsl:apply-templates select="@outputclass" mode="get-value-for-class"/>
  </xsl:variable>
  <!-- Revised design with DITA-OT 1.5: include class ancestry if requested; 
       combine user output class with element default, giving priority to the user value. -->
  <xsl:if test="string-length(normalize-space(concat($outputclass-attribute,$using-output-class,$ancestry))) &gt; 0">
    <xsl:attribute name="class">
      <xsl:value-of select="$ancestry"/>
      <xsl:if test="string-length(normalize-space($ancestry)) &gt; 0 and 
                    string-length(normalize-space($using-output-class)) &gt; 0"><xsl:text> </xsl:text></xsl:if>
      <xsl:value-of select="$using-output-class"/>
      <xsl:if test="string-length(normalize-space(concat($ancestry,$using-output-class))) &gt; 0 and
                    string-length(normalize-space($outputclass-attribute)) &gt; 0"><xsl:text> </xsl:text></xsl:if>
      <xsl:value-of select="$outputclass-attribute"/>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="contains($outputclass-attribute, 'filter_product')">
        <xsl:attribute name="filter">product=<xsl:value-of select="substring-after($outputclass-attribute, 'filter_product_')" /></xsl:attribute>
      </xsl:when>
      <xsl:when test="contains($outputclass-attribute, 'filter_os')">
        <xsl:choose>
          <xsl:when test="contains($outputclass-attribute, '_not_')">
            <xsl:attribute name="filter">os!=<xsl:value-of select="substring-after($outputclass-attribute, 'filter_os_not_')" /></xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="filter">os=<xsl:value-of select="substring-after($outputclass-attribute, 'filter_os_')" /></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:when test="contains($outputclass-attribute, 'filter_plugin')">
        <xsl:choose>
          <xsl:when test="contains($outputclass-attribute, '_not_')">
            <xsl:attribute name="filter">plugin!=<xsl:value-of select="substring-after($outputclass-attribute, 'filter_plugin_not_')" /></xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="filter">plugin=<xsl:value-of select="substring-after($outputclass-attribute, 'filter_plugin_')" /></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
	  <xsl:when test="contains($outputclass-attribute, 'id_')">
        <xsl:attribute name="id"><xsl:value-of select="substring-after($outputclass-attribute, 'id_')" /></xsl:attribute>
      </xsl:when>
      <xsl:otherwise/>
    </xsl:choose>    
  </xsl:if>
</xsl:template>

  <!-- Locates outputclass attributes that contain product filters
  and replaces them with filter attributes that point to products. -->
  <xsl:template match="@outputclass">
    <xsl:message terminate="yes">Entering template <xsl:value-of select="."/></xsl:message>
    <xsl:choose>
      <xsl:when test="contains(., 'filter_product')">
        <xsl:attribute name="filter">product=<xsl:value-of select="substring-after(., 'filter_product_')" /></xsl:attribute>
      </xsl:when>
      <xsl:when test="contains(., 'filter_os')">
        <xsl:choose>
          <xsl:when test="contains(., '_not_')">
            <xsl:attribute name="filter">os!=<xsl:value-of select="substring-after(., 'filter_os_not_')" /></xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="filter">os=<xsl:value-of select="substring-after(., 'filter_os_')" /></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:when test="contains(., 'filter_plugin')">
        <xsl:message terminate="yes">Filter plugin test <xsl:value-of select="."/></xsl:message>
        <xsl:choose>
          <xsl:when test="contains(., '_not_')">
            <xsl:attribute name="filter">plugin!=<xsl:value-of select="substring-after(., 'filter_plugin_not_')" /></xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:message terminate="yes">Create filter attribute</xsl:message>
            <xsl:attribute name="filter">plugin=<xsl:value-of select="substring-after(., 'filter_plugin_')" /></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
	  <xsl:when test="contains(., 'id_')">
        <xsl:attribute name="id"><xsl:value-of select="substring-after(., 'id_')" /></xsl:attribute>
      </xsl:when>
    </xsl:choose>
    <xsl:message terminate="yes">Write class <xsl:value-of select="."/></xsl:message>
    <xsl:attribute name="class"><xsl:value-of select="."/></xsl:attribute>
  </xsl:template>
    
<!--
##### End of fixes for Eclipse extensions #####
-->

<!-- 
##### OVERRIDE FOR "GET READY" TWISTIES #####
added 07/21/2006 jta 
these are based on IDWB 3.8.6 templates 
additions or changes noted by ******                   
-->

<xsl:template match="*[contains(@class,' topic/note ')][@outputclass='getready'][@type='other']" name="topic.note.getready">
	<xsl:if test="ancestor::*[contains(@class,' task/prereq ')]">
	  <xsl:call-template name="spec-title"/>
	  <div class="getready">
	   <div class="collapseheadgetready">
	  	  <a href="javascript:void(0)" class="collapsehead" onclick="collapse(this)">
	       	  <xsl:value-of select="@othertype" />
		  </a>
	   </div>
	   <div class="collapsecontent">
	   	 <xsl:apply-templates />
	   </div>
	 </div>
	 <div class="learnmorebase">
	   <xsl:text> </xsl:text>
	 </div>
	 <xsl:value-of select="$newline"/>
   </xsl:if>
</xsl:template>

<!-- 
##### RSS AND WEB FEEDS #####
Creates a link to Web feeds specified by writers in note elements
that have outputclass attibutes with the value 'webfeed'.
dwh :: 17.May.2007 
-->

  <xsl:template match="*[contains(@class,' topic/note ')][@outputclass='webfeed']" name="topic.note.webfeed">
      <xsl:call-template name="spec-title"/>
      <xsl:value-of select="$newline"/>
      <div class="webfeed">
        <span class="notetitle">
          <xsl:element name="a">
            <xsl:attribute name="class">webfeed-link</xsl:attribute>
            <xsl:attribute name="title">Shows English articles</xsl:attribute>
            <xsl:attribute name="href">javascript:void(0)</xsl:attribute>
            <xsl:attribute name="onClick">getWebFeed('<xsl:value-of select="xref/@href" />',this);</xsl:attribute>
            <xsl:value-of select="xref" />
          </xsl:element>
        </span>
       </div>
  </xsl:template>
  
<!-- jta: moved template from tutorial section on 20090312, removed tutorial-only code; RTC UT task 5215 -->

  <!-- #### 'Learn More' notes #### -->
  <xsl:template match="*[contains(@class,' topic/note ')][@outputclass='learnmore']" name="topic.note.learnmore">
      <xsl:call-template name="spec-title"/>
      <xsl:if test="@type='other'">
        <xsl:value-of select="$newline"/>
        <div class="learnmore">
          <xsl:call-template name="commonattributes"/>
          <xsl:call-template name="setidaname"/>
          <div class="collapseheadlearnmore">
            <a href="javascript:void(0)" class="collapsehead" onclick="collapse(this)">
            <xsl:value-of select="@othertype" />
            </a>
          </div>
          <div class="collapsecontent">
            <!-- <xsl:value-of select="." /> -->
            <xsl:apply-templates />
          </div>
         </div>
       <div class="learnmorebase"><xsl:text> </xsl:text></div>
     </xsl:if>
  </xsl:template>


<!-- 
################################
# TUTORIAL SPECIFIC TEMPLATES  #
################################
-->

  <!-- ##### Override Tutorial breadcrumbs #### --> 
  <xsl:template name="tutbreadcrumb">  
  	<!--<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text> -->
  	<!--<xsl:text disable-output-escaping="yes">&lt;!- -&gt;</xsl:text> -->
  	<!-- 20090408:JA commented previous line, do nothing -->
  </xsl:template>
  
  <!-- #### Tutorial 'Show Me' xrefs #### -->
  <xsl:template match="/*[contains(@class, ' tutorialLesson/tutorialLesson ') or contains(@class, ' tutorialSummary/tutorialSummary ') or contains(@class, ' tutorialModule/tutorialModule ') or contains(@class, ' tutorial/tutorial ') or contains(@class, ' tutorialIntro/tutorialIntro ') or contains(@class,' authorInfo/authorInfo ')]//*[contains(@class,' topic/xref ')][@outputclass='showme']" name="topic.tutorial.xref">
    <xsl:value-of select="$newline"/>
    <div class="showme">
      <div class="collapseheadshowme">
        <a href="javascript:void(0)" class="collapsehead" onclick="collapse(this)"><xsl:value-of select="." /></a>
      </div>
      <div class="collapsecontent">
        <div class="section">
          <xsl:choose>
            <!-- Parse values of 'otherprops' attribute. -->
            <xsl:when test="boolean(@otherprops)">
              <xsl:variable name="width">
                <xsl:value-of select="substring-before(@otherprops, 'x')" />
              </xsl:variable>
              <xsl:variable name="height">
                <xsl:value-of select="substring-after(@otherprops, 'x')" />
              </xsl:variable>
              <xsl:element name="object">
                <xsl:attribute name="id">11</xsl:attribute>
                <xsl:attribute name="codebase">http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab                    </xsl:attribute>
                <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
                <xsl:attribute name="classid">clsid:D27CDB6E-AE6D-11cf-96B8-444553540000</xsl:attribute>
                <xsl:attribute name="data"><xsl:value-of select="@href" /></xsl:attribute>
                <xsl:attribute name="width"><xsl:value-of select="$width" /></xsl:attribute>
                <xsl:attribute name="height"><xsl:value-of select="$height" /></xsl:attribute>
                <xsl:element name="param">
                  <xsl:attribute name="name">movie</xsl:attribute>
                  <xsl:attribute name="value"><xsl:value-of select="@href" /></xsl:attribute>
                </xsl:element>
                <xsl:element name="param">
                  <xsl:attribute name="name">pluginspace</xsl:attribute>
                  <xsl:attribute name="value">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
                </xsl:element>
                <xsl:element name="embed">
                  <xsl:attribute name="name">11</xsl:attribute>
                  <xsl:attribute name="width"><xsl:value-of select="$width" /></xsl:attribute>
                  <xsl:attribute name="height"><xsl:value-of select="$height" /></xsl:attribute>
                  <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
                  <xsl:attribute name="pluginspace">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
                  <xsl:attribute name="src"><xsl:value-of select="@href" /></xsl:attribute>
                </xsl:element>
              </xsl:element>
            </xsl:when>
            <!-- Default values for width and height attributes. -->
            <xsl:otherwise>
              <xsl:element name="object">
                <xsl:attribute name="id">11</xsl:attribute>
                <xsl:attribute name="codebase">http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab                    </xsl:attribute>
                <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
                <xsl:attribute name="classid">clsid:D27CDB6E-AE6D-11cf-96B8-444553540000</xsl:attribute>
                <xsl:attribute name="data"><xsl:value-of select="@href" /></xsl:attribute>
                <xsl:attribute name="width">800</xsl:attribute>
                <xsl:attribute name="height">600</xsl:attribute>
                <xsl:element name="param">
                  <xsl:attribute name="name">movie</xsl:attribute>
                  <xsl:attribute name="value"><xsl:value-of select="@href" /></xsl:attribute>
                </xsl:element>
                <xsl:element name="param">
                  <xsl:attribute name="name">pluginspace</xsl:attribute>
                  <xsl:attribute name="value">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
                </xsl:element>
                <xsl:element name="embed">
                  <xsl:attribute name="name">11</xsl:attribute>
                  <xsl:attribute name="width">800</xsl:attribute>
                  <xsl:attribute name="height">600</xsl:attribute>
                  <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
                  <xsl:attribute name="pluginspace">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
                  <xsl:attribute name="src"><xsl:value-of select="@href" /></xsl:attribute>
                </xsl:element>
              </xsl:element>
            </xsl:otherwise>
          </xsl:choose>
        </div>
      </div>
    </div>
    <div class="showmebase"><xsl:text> </xsl:text></div>
  </xsl:template>

<!-- 

	# THIS IS OVERRIDING THE tutorialBody TEMPLATE FROM tutorialspeclink.xsl
    #
    # ONE LINE CHANGE FOR A WEIRD PROBLEM WITH EHS
    # CONVERTING EMPTY DIVS TO SELF-CLOSING DIVS
    # AND THE CSS THEN GOING WONKY FOR ENTIRE PAGE
    # 
    # Also moving the Prev/Next links inside the header and before the footer
    # 
    # smp :: 2008:04:18

-->      
  <xsl:template name="tutorialBody">
    <body>
      <xsl:call-template name="setidaname"/>
      <xsl:value-of select="$newline"/>
      <xsl:call-template name="flagit"/>
      <xsl:call-template name="start-revflag"/>

      <!-- 20090408:JA commenting out, unneeded due to tutbreadcrumb template changes -->
      <!-- TutSpec :: breadcrumb -->
      <!-- <xsl:choose> -->
        <!-- <xsl:when test="boolean(//*[contains(@class,' topic/link ')][@role='tutbreadcrumb'])"> -->
          <!-- 20090408:JA commenting out, unneeded due to tutbreadcrumb template changes -->
          <!-- <div class="breadcrumb"> -->
          <!--  <xsl:call-template name="tutbreadcrumb" /> -->
          <!-- </div> -->
        <!-- </xsl:when> -->
        <!-- <xsl:otherwise> -->
          <!-- smp: THIS IS THE CHANGED LINE --> 
          <!--<div class="breadcrumb"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></div>-->
          <!--<div class="breadcrumb"><xsl:text disable-output-escaping="yes">&lt;!- no breadcrumb entries -&gt;</xsl:text></div> -->
        <!-- </xsl:otherwise> -->
      <!-- </xsl:choose> -->

      <xsl:call-template name="gen-user-header"/>  <!-- include user's XSL running header here -->
      <xsl:call-template name="processHDR"/>
      <!-- Include a user's XSL call here to generate a toc based on what's a child of topic -->
      <xsl:call-template name="gen-user-sidetoc"/>

      <!-- smp: MOVED TO AFTER HEADERS -->
      <!-- Insert previous-next links at the top of each topic. -->
      <xsl:call-template name="tutprevnext" />

      <xsl:apply-templates/> <!-- this will include all things within topic; therefore, -->
       <!-- title content will appear here by fall-through -->
       <!-- followed by prolog (but no fall-through is permitted for it) -->
       <!-- followed by body content, again by fall-through in document order -->
       <!-- followed by related links -->
       <!-- followed by child topics by fall-through -->

      <!-- smp: MOVED TO BEFORE FOOTERS -->
      <!-- Insert previous-home-next links at the bottom of each topic. -->
      <xsl:call-template name="tutprevnext" />

      <xsl:call-template name="gen-endnotes"/>    <!-- include footnote-endnotes -->
      <xsl:call-template name="gen-user-footer"/> <!-- include user's XSL running footer here -->
      <xsl:call-template name="processFTR"/>      <!-- Include XHTML footer, if specified -->
      <xsl:call-template name="end-revflag"/>

    </body>
    <xsl:value-of select="$newline"/>

  </xsl:template>




<!-- 
####################################
# END TUTORIAL SPECIFIC TEMPLATES  #
####################################
-->
  
<!-- 
###############################
# SAMPLES SPECIFIC TEMPLATES  #
###############################
-->
  <!-- JavaScript variables -->
  <xsl:variable name="jscriptImport" select="'javaScript:importPISample'" />
  <xsl:variable name="jscriptTutorial" select="'javaScript:linkTutorial'" />
  
  <!-- Match sample and call modified page setup. -->
  <xsl:template match="/*[contains(@class, ' sample/sample ')]" priority="1" name="sample_element">
    <xsl:call-template name="sample-setup"/>
  </xsl:template>

  <!-- Match sampleSetup and sampleDetails and call standard page
  setup -->
  <xsl:template match="/*[contains(@class, ' sampleSetup/sampleSetup ') or contains(@class, ' sampleDetails/sampleDetails ')]" priority="1" name="sampleSetup_element">
    <xsl:call-template name="sampleOther-setup"/>
  </xsl:template>

  <!-- Modified default page layout for sample. -->
  <xsl:template name="sample-setup">
    <html>
      <xsl:call-template name="setTopicLanguage"/>
      <xsl:value-of select="$newline"/>
      <xsl:call-template name="chapterHead"/>
      <xsl:call-template name="sampleBody"/>
    </html>
  </xsl:template>

  <xsl:template name="sampleBody">
    <body>
      <xsl:call-template name="setidaname"/>
      <xsl:value-of select="$newline"/>
      <xsl:call-template name="flagit"/>
      <xsl:call-template name="start-revflag"/>

      <xsl:call-template name="gen-user-header"/>  <!-- include user's XSL running header here -->
      <xsl:call-template name="processHDR"/>
      <!-- Include a user's XSL call here to generate a toc based on what's a child of topic -->
      <xsl:call-template name="gen-user-sidetoc"/>

      <!-- Calling individual templates to modify processing order
      for samples topics -->
      <xsl:apply-templates select="*[contains(@class,' topic/title ')][parent::*[contains(@class,' sample/sample ')]]" />

      <xsl:apply-templates select="*[contains(@class,' topic/shortdesc ')][parent::*[contains(@class,' sample/sample ')]]" mode="outofline" />

      <xsl:apply-templates select="*[contains(@class,' sample/sampleBody ')]/*[contains(@class,' topic/section sample/timeRequired ')]" />
       <xsl:apply-templates select="*[contains(@class,' sample/sampleBody ')]/*[contains(@class,' topic/section sample/samplePrereq ')]" />

      <xsl:apply-templates select="*[contains(@class,' sample/sampleRelatedLinks ')]" />

      <xsl:apply-templates select="*[contains(@class,' sample/sampleBody ')]/*[contains(@class,' topic/section sample/sampleDesc ')]" />

      <xsl:apply-templates select="*[contains(@class,' sample/sampleBody ')]/*[contains(@class,' topic/section sample/sampleGraphics ')]" />

      <xsl:call-template name="gen-endnotes"/>    <!-- include footnote-endnotes -->
      <xsl:call-template name="gen-user-footer"/> <!-- include user's XSL running footer here -->
      <xsl:call-template name="processFTR"/>      <!-- Include XHTML footer, if specified -->
      <xsl:call-template name="end-revflag"/>

    </body>
    <xsl:value-of select="$newline"/>

  </xsl:template>

  <!-- Modifiying standard page layout for sampleSetp and
  sampleDetails. -->
  <xsl:template name="sampleOther-setup">
    <html>
      <xsl:call-template name="setTopicLanguage"/>
      <xsl:value-of select="$newline"/>
      <xsl:call-template name="chapterHead"/>
      <xsl:call-template name="sampleSetupBody"/>
    </html>
  </xsl:template>

  <xsl:template name="sampleSetupBody">
    <body>
      <!-- Already put xml:lang on <html>; do not copy to body-->
      <xsl:call-template name="setidaname"/>
      <xsl:value-of select="$newline"/>
      <xsl:call-template name="flagit"/>
      <xsl:call-template name="start-revflag"/>
      <xsl:call-template name="generateBreadcrumbs"/>
      <xsl:call-template name="gen-user-header"/>  <!-- include user's XSL running header here -->
      <xsl:call-template name="processHDR"/>
      <!-- Include a user's XSL call here to generate a toc based on what's a child of topic -->
      <xsl:call-template name="gen-user-sidetoc"/>

      <!-- Link to parent from sampleDetails and sampleSetup -->
      <xsl:if test="self::*[contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]">
        <div class="breadcrumbs">
          <xsl:call-template name="sampparent" />
        </div>
      </xsl:if>

      <xsl:apply-templates/> <!-- this will include all things within topic; therefore, -->
                             <!-- title content will appear here by fall-through -->
                             <!-- followed by prolog (but no fall-through is permitted for it) -->
                             <!-- followed by body content, again by fall-through in document order -->
                             <!-- followed by related links -->
                             <!-- followed by child topics by fall-through -->

      <xsl:call-template name="gen-endnotes"/>
      <xsl:call-template name="gen-user-footer"/> <!-- include user's XSL running footer here -->
      <xsl:call-template name="processFTR"/>      <!-- Include XHTML footer, if specified -->
      <xsl:call-template name="end-revflag"/>
    </body>
    <xsl:value-of select="$newline"/>
  </xsl:template>

  <!-- Sample title override -->
  <xsl:template match="/*[contains(@class, ' sample/sample ') or contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]/*[contains(@class,' topic/title ')]" name="topic.sampleTitle">
    <xsl:param name="headinglevel">
      <xsl:choose>
          <xsl:when test="count(ancestor::*[contains(@class,' topic/topic ')]) > 6">6</xsl:when>
          <xsl:otherwise><xsl:value-of select="count(ancestor::*[contains(@class,' topic/topic ')])"/></xsl:otherwise>
      </xsl:choose>
    </xsl:param>
    <xsl:if test="$headinglevel=1" >
      <div class="title">
        <xsl:element name="h{$headinglevel}">
          <xsl:call-template name="commonattributes"/>
          <xsl:apply-templates/>
        </xsl:element>
      </div>
    </xsl:if>
    <xsl:value-of select="$newline"/>
  </xsl:template>

  <!-- sampleDesc -->
  <!-- 20080709:JA per RA, changed from xsl:template match="*[contains(@class,' topic/section sample/sampleDesc ')]" name="topic.sample.sampleDesc" -->
  <xsl:template match="*[contains(@class,' sample/sampleDesc ')]" name="topic.sample.sampleDesc">
    <div class="desc">
      <xsl:call-template name="commonattributes"/>
      <xsl:call-template name="gen-toc-id"/>
      <xsl:call-template name="setidaname"/>
      <xsl:call-template name="flagit"/>
      <xsl:variable name="revtest">
        <xsl:if test="@rev and not($FILTERFILE='') and ($DRAFT='yes')"> <!-- revision? -->
          <xsl:call-template name="find-active-rev-flag">               <!-- active? (revtest will be 1 when active)-->
            <xsl:with-param name="allrevs" select="@rev"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:variable>
      <xsl:choose>
        <xsl:when test="$revtest=1">   <!-- Rev is active - add the DIV -->
          <div class="{@rev}">
            <xsl:apply-templates select="."  mode="section-fmt" />
          </div>
        </xsl:when>
        <xsl:otherwise>  <!-- Rev wasn't active - process normally -->
          <xsl:apply-templates select="."  mode="section-fmt" />
        </xsl:otherwise>
      </xsl:choose>
    </div><xsl:value-of select="$newline"/>
  </xsl:template>

  <!--sampleGraphics  -->
  <!-- 20080709:JA per Robert Anderson, changed from xsl:template match="*[contains(@class,' topic/section sample/sampleGraphics ')]" name="topic.sample.sampleGraphics" -->
  <xsl:template match="*[contains(@class,' sample/sampleGraphics ')]" name="topic.sample.sampleGraphics">
    <div class="graphics gtext">
      <!--  p class="graphicsText">Click on images to expand view</p>-->
      <xsl:call-template name="commonattributes"/>
      <xsl:call-template name="gen-toc-id"/>
      <xsl:call-template name="setidaname"/>
      <xsl:call-template name="flagit"/>
      <xsl:variable name="revtest">
        <xsl:if test="@rev and not($FILTERFILE='') and ($DRAFT='yes')"> <!-- revision? -->
          <xsl:call-template name="find-active-rev-flag">               <!-- active? (revtest will be 1 when active)-->
            <xsl:with-param name="allrevs" select="@rev"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:variable>
      <xsl:choose>
        <xsl:when test="$revtest=1">   <!-- Rev is active - add the DIV -->
          <div class="{@rev}">
            <xsl:apply-templates select="."  mode="section-fmt" />
          </div>
        </xsl:when>
        <xsl:otherwise>  <!-- Rev wasn't active - process normally -->
          <xsl:apply-templates />
        </xsl:otherwise>
      </xsl:choose>
    </div><xsl:value-of select="$newline"/>
  </xsl:template>

  <!-- Process only sampleGraphics elements. -->
  <!--
  <xsl:template match="/*[contains(@class, ' sample/sample ') or contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]/*[contains(@class,' topic/body sample/sampleBody ')]/*[contains(@class,' topic/section sample/sampleGraphics ')]">
    <div class="gdesc"><xsl:apply-templates /></div>
  </xsl:template>
  -->
  <!-- Process only sampleGraphics/p elements.
  <xsl:template match="/*[contains(@class, ' sample/sample ') or contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]/*[contains(@class,' topic/body sample/sampleBody ')]/*[contains(@class,' topic/section sample/sampleGraphics ')]/*[contains(@class,' topic/p ')]">
       <div class="gdesc"><xsl:apply-templates /></div>
  </xsl:template>
  -->

  <!-- Process only sampleGraphics/p/image elements. -->
  <!-- 20080709: JA per RA, changed from xsl:template match="/*[contains(@class, ' sample/sample ') or contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]/*[contains(@class,' topic/body sample/sampleBody ')]/*[contains(@class,' topic/section sample/sampleGraphics ')]/*[contains(@class,' topic/p ')]/*[contains(@class, ' topic/image ')]" -->
  <xsl:template match="/*[contains(@class, ' sample/sample ') or contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]/*[contains(@class,' sample/sampleBody ')]/*[contains(@class,' sample/sampleGraphics ')]/*[contains(@class,' topic/p ')]/*[contains(@class, ' topic/image ')]">
  
      <div class="gimage">
      <script type="text/javascript"><xsl:text>displayImage("</xsl:text><xsl:value-of select="@href" /><xsl:text>","</xsl:text><xsl:value-of select="*[contains(@class, ' topic/alt ')]" /><xsl:text>")</xsl:text></script>
    </div>
   
    <!-- Use mode set to text-only because base transforms don't handle alt text -->

  </xsl:template>

  <!-- Process only sampleGraphics/image elements. -->
  <!-- 20080709:JA per RA, changed from xsl:template match="/*[contains(@class, ' sample/sample ') or contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]/*[contains(@class,' topic/body sample/sampleBody ')]/*[contains(@class,' topic/section sample/sampleGraphics ')]/*[contains(@class, ' topic/image ')]" -->
  <xsl:template match="/*[contains(@class, ' sample/sample ') or contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]/*[contains(@class,' sample/sampleBody ')]/*[contains(@class,' sample/sampleGraphics ')]/*[contains(@class, ' topic/image ')]">

      <div class="gimage">
      <script type="text/javascript"><xsl:text>displayImage("</xsl:text><xsl:value-of select="@href" /><xsl:text>","</xsl:text><xsl:value-of select="normalize-space(*[contains(@class, ' topic/alt ')])" /><xsl:text>")</xsl:text></script>
    </div>
  
  </xsl:template>

  <!-- Process only sampleGraphics/p/b elements. -->
  <!-- 20080709:JA per RA, changed from xsl:template match="/*[contains(@class, ' sample/sample ') or contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]/*[contains(@class,' topic/body sample/sampleBody ')]/*[contains(@class,' topic/section sample/sampleGraphics ')]/*[contains(@class,' topic/p ')]/*[contains(@class, ' topic/ph hi-d/b ')]" -->
  <xsl:template match="/*[contains(@class, ' sample/sample ') or contains(@class, ' sampleDetails/sampleDetails ') or contains(@class, ' sampleSetup/sampleSetup ')]/*[contains(@class,' sample/sampleBody ')]/*[contains(@class,' sample/sampleGraphics ')]/*[contains(@class,' topic/p ')]/*[contains(@class, ' topic/ph hi-d/b ')]">
    <strong><xsl:value-of select="." /></strong>
  </xsl:template>



  <!-- timeRequired -->
  <!-- 20080709:JA per RA, changed from xsl:template match="*[contains(@class,' topic/section sample/timeRequired ')]" name="topic.sample.timeRequired" -->
  <xsl:template match="*[contains(@class,' sample/timeRequired ')]" name="topic.sample.timeRequired">
    <div class="sampleTimeRequired">
      <xsl:call-template name="commonattributes"/>
      <xsl:call-template name="gen-toc-id"/>
      <xsl:call-template name="setidaname"/>
      <xsl:call-template name="flagit"/>
      <xsl:variable name="revtest">
        <xsl:if test="@rev and not($FILTERFILE='') and ($DRAFT='yes')"> <!-- revision? -->
          <xsl:call-template name="find-active-rev-flag">               <!-- active? (revtest will be 1 when active)-->
            <xsl:with-param name="allrevs" select="@rev"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:variable>
      <xsl:choose>
        <xsl:when test="$revtest=1">   <!-- Rev is active - add the DIV -->
          <div class="{@rev}"><xsl:apply-templates select="."  mode="section-fmt" /></div>
        </xsl:when>
        <xsl:otherwise>  <!-- Rev wasn't active - process normally -->
          <xsl:apply-templates select="."  mode="section-fmt" />
        </xsl:otherwise>
      </xsl:choose>
    </div><xsl:value-of select="$newline"/>
  </xsl:template>

  <!-- sampleRelatedLinks -->
  <xsl:template match="*[contains(@class,' sample/sampleRelatedLinks ')]" name="topic.sample.sampleRelatedLinks">
    <div class="sampleLinks">
      <div class="impLinks">
        <!-- Process first seeSetup element only -->
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-setup'][1]" />
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-import']" />
        <!-- Process remaining seeSetup elements -->
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-setup'][not(position()=1)]" />
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-configure']" />
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-details'][1]" />
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-demo']" />
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-build']" />
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-how']" />
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-tutorial']" />
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-details'][not(position()=1)]" />
        <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-help']" />
             <xsl:apply-templates select="*[contains(@class,' topic/link ')][@outputclass='link-sample']" />
      </div>
    </div>
    <xsl:value-of select="$newline"/>
  </xsl:template>

  <!-- link -->
  <xsl:template match="*[contains(@class,' topic/link ')][parent::*[contains(@class,' sample/sample ')]]" name="topic.sample.link">
    <div class="detailsLink">
      <xsl:call-template name="makeseesamplink" />
    </div><xsl:value-of select="$newline"/>
  </xsl:template>

  <!-- Make link -->
  <xsl:template name="makeseesamplink">
    <xsl:call-template name="linkdupinfo"/>
    <xsl:call-template name="flagit"/>
    <xsl:call-template name="start-revflag"/>
    <xsl:element name="a">
      <xsl:if test="boolean(@outputclass)">
        <!-- Apply common attributes, including outputclass, when
        the outputclass attribute exists. -->
        <xsl:call-template name="commonattributes"/>
      </xsl:if>
      <xsl:attribute name="href">
        <xsl:call-template name="href"/>
      </xsl:attribute>
      <xsl:if test="@scope='external' or @type='external' or ((@format='PDF' or @format='pdf') and not(@scope='local'))">
        <xsl:attribute name="target">_blank</xsl:attribute>
      </xsl:if>
      <!--create hover help if desc exists-->
      <xsl:if test="*[contains(@class, ' topic/desc ')]">
        <xsl:variable name="hoverhelp">
          <xsl:apply-templates select="*[contains(@class, ' topic/desc ')]" mode="text-only"/>
        </xsl:variable>
        <xsl:attribute name="title">
          <xsl:value-of select="normalize-space($hoverhelp)"/>
        </xsl:attribute>
      </xsl:if>
      <!--use linktext as linktext if it exists, otherwise use href as linktext-->
      <xsl:choose>
        <xsl:when test="*[contains(@class, ' topic/linktext ')]">
          <xsl:apply-templates select="*[contains(@class, ' topic/linktext ')]"/>
        </xsl:when>
        <xsl:otherwise>
          <!--use href-->
          <xsl:call-template name="href"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:element>
    <xsl:call-template name="end-revflag"/>
  </xsl:template>

  <xsl:template name="sampparent">
    <xsl:for-each select="//*[contains(@class,' topic/link ')][@role='sampparent']">
      <xsl:element name="a">
        <xsl:attribute name="href">
          <xsl:value-of select="substring-before(@href, '.dita')"/>
          <xsl:text>.</xsl:text>
          <xsl:value-of select="$OUTEXT"/>
        </xsl:attribute>
        <xsl:value-of select="linktext" />
      </xsl:element>
    </xsl:for-each>
  </xsl:template>



<!-- 
###################################
# END SAMPLES SPECIFIC TEMPLATES  #
###################################
-->
   <!-- override for Syntax diagrams using idwb 4.0 patch 01 -->
   <!-- 20090408: JA commented out for IDWB 4.1 -->
   <!-- 
   <xsl:character-map name="cm1">
     <xsl:output-character character="&lt;" string="&amp;lt;"/>
     <xsl:output-character character="&amp;" string="&amp;amp;"/>
   </xsl:character-map>
   -->

<xsl:template match="*[contains(@class, ' pr-d/syntaxdiagram ')]" mode="process-after-doc">
  <xsl:variable name="synfilename">
    <xsl:value-of select="substring-before($FILENAME,'.dita')"/>
    <xsl:text>_syn</xsl:text>
    <xsl:number level="any"/>
    <xsl:text>.syn</xsl:text>
  </xsl:variable>
  <xsl:choose>
    <xsl:when test="ancestor::*[contains(@class,' topic/draft-comment ') or contains(@class,' topic/required-cleanup ')] and
                    $DRAFT='no'">
    </xsl:when>
    <xsl:otherwise>
      <xsl:result-document href="{$FILEREF}{$WORKDIR}{$synfilename}" method="text" use-character-maps="cm1">
        <xsl:call-template name="output-railroad-syntax-diagram"/>
      </xsl:result-document>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>
  
</xsl:stylesheet>
